Class: Eco::API::UseCases::Default::Utils::MergeCsv
- Inherits:
-
Custom::UseCase
- Object
- Loaders::Base
- Common::Loaders::CaseBase
- Common::Loaders::UseCase
- Custom::UseCase
- Eco::API::UseCases::Default::Utils::MergeCsv
- Defined in:
- lib/eco/api/usecases/default/utils/merge_csv_case.rb,
lib/eco/api/usecases/default/utils/cli/merge_csv_cli.rb
Overview
Note:
you might run first the sort-csv case.
Note:
at the moment, it does NOT add new fields from the merge file. It only uses the headers of the original file.
Note:
you must inherit from this case and define the constants.
MERGE_BY_FIELD = 'target_csv_field'.freeze
those not merged are overridden
JOINED_FIELDS = [ 'joined_field_1', 'joined_field_2', 'joined_field_3', ].freeze
This script assumes that for the MERGE_BY_FIELD rows are consecutive.
Defined Under Namespace
Classes: Cli
Instance Method Summary collapse
Methods inherited from Common::Loaders::UseCase
Methods included from Common::Loaders::UseCase::CliIdentify
Methods included from Common::Loaders::UseCase::TargetModel
Methods included from Common::Loaders::UseCase::Type
Methods inherited from Common::Loaders::CaseBase
#name, name_only_once!, original_name
Constructor Details
This class inherits a constructor from Eco::API::Common::Loaders::UseCase