Class: Eco::CliDefault::Workflow

Inherits:
API::Common::Loaders::Workflow show all
Defined in:
lib/eco/cli_default/workflow.rb,
lib/eco/cli_default/workflow/end.rb,
lib/eco/cli_default/workflow/load.rb,
lib/eco/cli_default/workflow/report.rb,
lib/eco/cli_default/workflow/options.rb,
lib/eco/cli_default/workflow/usecases.rb,
lib/eco/cli_default/workflow/launch_jobs.rb,
lib/eco/cli_default/workflow/post_launch.rb,
lib/eco/cli_default/workflow/rescued_exception.rb

Overview

TODO:

The ones below:

  1. Identify the target model earlier (required_data?), provided that we can granulate the workflow.
  2. Try to modularize the options check/dig.
  3. Review the cli.config.people and see if it can be renamed to cli.config.data and load it based on the target model.
  4. Decouple into multiple classes that can be loaded based on the target model. Or either define different workflows that assembly those classes?
  5. Right on the load:data stage, set the io model based on (1).

Defined Under Namespace

Classes: End, LaunchJobs, Load, Options, PostLaunch, Report, RescuedException, Usecases

Method Summary

Methods inherited from API::Common::Loaders::Workflow

workflow