Module: Eco::Language::Delegation::ConstDelegator
- Defined in:
- lib/eco/language/delegation/const_delegator.rb
Overview
Note:
it includes DelegatedClass
Note:
it looks up the constant via delegated_class. This is because
on Delegator approaches, the intance object (self) points to the
delegated object, which doesn't allow to refer to self.class to
implement a delegation of constants that other way.
For example, self.class::CONSTANT will not point to the delegator
class constant, but to the constant of the delegated object's class.
Module that is to be used with ruby Delegator or related helpers,
such as SimpleDelegator or Forwardable.
Defined Under Namespace
Modules: ClassMethods