Class: Eco::Language::Models::Workflow
- Extended by:
- Klass::HelpersBuilt, Hierarchy
- Defined in:
- lib/eco/language/models/workflow.rb
Overview
Execution workflow
Direct Known Subclasses
Instance Attribute Summary collapse
-
#config ⇒ Object
readonly
Returns the value of attribute config.
Attributes included from Hierarchy
Class Method Summary collapse
Instance Method Summary collapse
-
#after(key = nil) {|stage_workflow, io| ... } ⇒ Eco::API::Session::Config::Workflow
Used in configuration time add previous
callbacksafter theoncallback of the (sub)stagekeyis actuallyrun. -
#before(key = nil) {|stage_workflow, io| ... } ⇒ Eco::API::Session::Config::Workflow
Used in configuration time add previous
callbacksbefore theoncallback of the (sub)stagekeyis actuallyrun. -
#exit_handle(&block) ⇒ Object
Called on
SystemExitexception. -
#for(key = nil) {|stage_workflow| ... } ⇒ Eco::API::Session::Config::Workflow
(also: #with)
Used in configuration time to configure the workflow of the target (sub)stage
key. -
#initialize(name = nil, config:, _parent: self) ⇒ Workflow
constructor
rubocop:disable Lint/UnderscorePrefixedVariableName.
- #name(with_path: false) ⇒ Object
-
#on(key = nil) {|stage_workflow, io| ... } ⇒ Eco::API::Session::Config::Workflow
Used in configuration time to define the behaviour the target (sub)stage
key. -
#pending? ⇒ Boolean
Has this stage run yet?.
-
#rescue {|exception, io| ... } ⇒ Eco::API::Session::Config::Workflow
(also: #exception)
When there is an
Exception, you might have defined somecallbackto do something with it (i.e. register, email). -
#run(key = nil, io:) {|stage_workflow, io| ... } ⇒ Eco::API::Session::Config::Workflow
Used in run time to execute the workflow of the (sub)stage
key. -
#skip! ⇒ Object
Do not run this stage!.
-
#skip? ⇒ Boolean
Has this stage been marked as to be skipped.
Methods included from Klass::InheritableClassVars
#inheritable_attrs, #inheritable_class_vars, #inherited
Methods included from Klass::Naming
#instance_variable_name, #to_constant
Methods included from Klass::Hierarchy
Methods included from Klass::Builder
Methods included from Klass::Uid
Methods included from Klass::Resolver
#class_resolver, #resolve_class
Methods included from Klass::Const
#if_const, #redef_without_warning
Methods included from Hierarchy
Constructor Details
#initialize(name = nil, config:, _parent: self) ⇒ Workflow
rubocop:disable Lint/UnderscorePrefixedVariableName
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/eco/language/models/workflow.rb', line 37 def initialize(name = nil, config:, _parent: self) # rubocop:disable Lint/UnderscorePrefixedVariableName @config = config @name = name @stages = {} @_parent = _parent @pending = true # moments @on = nil @before = [] @after = [] end |
Instance Attribute Details
#config ⇒ Object (readonly)
Returns the value of attribute config.
35 36 37 |
# File 'lib/eco/language/models/workflow.rb', line 35 def config @config end |
Class Method Details
.model ⇒ Object
12 13 14 |
# File 'lib/eco/language/models/workflow.rb', line 12 def model super || {} end |
.stages ⇒ Object
8 9 10 |
# File 'lib/eco/language/models/workflow.rb', line 8 def stages model_attrs end |
.validate_stage!(stage) ⇒ Object
16 17 18 19 20 21 |
# File 'lib/eco/language/models/workflow.rb', line 16 def validate_stage!(stage) return true if stages.include?(stage) msg = "Unknown Workflow stage '#{stage}'. Should be any of #{stages}" raise ArgumentError, msg end |
Instance Method Details
#after(key = nil) {|stage_workflow, io| ... } ⇒ Eco::API::Session::Config::Workflow
- it will not
yieldit immediately, but when the workflow reaches the target stage - in this case, you can define multiple
callbacks
Used in configuration time add previous callbacks after the on callback
of the (sub)stage key is actually run
197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/eco/language/models/workflow.rb', line 197 def after(key = nil, &block) msg = 'A block should be given.' raise ArgumentError, msg unless block_given? if key stage(key).after(&block) else @after.push(block) end self end |
#before(key = nil) {|stage_workflow, io| ... } ⇒ Eco::API::Session::Config::Workflow
- it will not
yieldit immediately, but when the workflow reaches the target stage - in this case, you can define multiple
callbacks
Used in configuration time add previous callbacks
before the on callback of the (sub)stage key is actually run
170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/eco/language/models/workflow.rb', line 170 def before(key = nil, &block) msg = 'A block should be given.' raise ArgumentError, msg unless block_given? if key stage(key).before(&block) else @before.push(block) end self end |
#exit_handle(&block) ⇒ Object
Called on SystemExit exception
149 150 151 152 153 154 |
# File 'lib/eco/language/models/workflow.rb', line 149 def exit_handle(&block) return @exit_handle unless block_given? @exit_handle = block self end |
#for(key = nil) {|stage_workflow| ... } ⇒ Eco::API::Session::Config::Workflow Also known as: with
- if a
blockis provided it willyieldthe target stage immediately - a
blockis only required whenkeyhas not been specified.
Used in configuration time to configure the workflow of the target (sub)stage key
94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/eco/language/models/workflow.rb', line 94 def for(key = nil, &block) msg = "With no 'key', a block should be given." raise ArgumentError, msg unless key || block_given? tap do next yield(self) unless key next stage(key).for(&block) if block_given? return stage(key) end end |
#name(with_path: false) ⇒ Object
51 52 53 54 55 |
# File 'lib/eco/language/models/workflow.rb', line 51 def name(with_path: false) return @name if !with_path || root? [@_parent.name(with_path: true), @name].compact.join('.') end |
#on(key = nil) {|stage_workflow, io| ... } ⇒ Eco::API::Session::Config::Workflow
if a block is provided it will not yield the target stage immediately,
but when the workflow reaches the stage
Used in configuration time to define the behaviour the target (sub)stage key
118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/eco/language/models/workflow.rb', line 118 def on(key = nil, &block) msg = 'A block should be given.' raise ArgumentError, msg unless block_given? if key stage(key).on(&block) else @on = block end self end |
#pending? ⇒ Boolean
it does not include sub-stages that run before
Has this stage run yet?
60 61 62 |
# File 'lib/eco/language/models/workflow.rb', line 60 def pending? @pending end |
#rescue {|exception, io| ... } ⇒ Eco::API::Session::Config::Workflow Also known as: exception
When there is an Exception, you might have defined some callback
to do something with it (i.e. register, email)
139 140 141 142 143 144 |
# File 'lib/eco/language/models/workflow.rb', line 139 def rescue(&block) return @rescue unless block_given? @rescue = block self end |
#run(key = nil, io:) {|stage_workflow, io| ... } ⇒ Eco::API::Session::Config::Workflow
if a block is not provided:
- it will run the
beforecallbacks defined during the configuration time - it will run the workflow of any defined substage of the
keystage - it will run the
oncallback defined during the configuration time - it will mark the stage as not
pending?. - it will run the
aftercallbacks defined during the configuration time
if a block is provided:
- it will not run the workflow of the substages to
keystage - it will not run the
callbackforondefined during the configuration time - it will rather
yieldthe target stage after all thebeforecallbacks have been run - aside of this, the rest will be the same as when the block is provided (see previous note)
[if the object returned by before, after and run callbacks
is not an INPUT_OUTPUT_CLASS, the original io object will be returned instead.
Used in run time to execute the workflow of the (sub)stage key
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/eco/language/models/workflow.rb', line 233 def run(key = nil, io:, &block) raise 'Missing BaseIO object' unless io.is_a?(input_output_class) rescuable(io) do if key io = io_result(io: io) do stage(key).run(io: io, &block) end elsif pending? io = run_before(io) io = run_it(io, &block) unless skip? io = run_after(io) end io ensure @pending = false end end |
#skip! ⇒ Object
Do not run this stage!
65 66 67 68 |
# File 'lib/eco/language/models/workflow.rb', line 65 def skip! @skip = true @pending = false end |
#skip? ⇒ Boolean
Has this stage been marked as to be skipped
75 76 77 78 79 80 |
# File 'lib/eco/language/models/workflow.rb', line 75 def skip? return @skip if instance_variable_defined?(:@skip) return false if root? @_parent.skip? end |