Class: Ecoportal::API::V1::Person
- Inherits:
-
Object
- Object
- Ecoportal::API::V1::Person
- Defined in:
- lib/eco/api/common/version_patches/ecoportal_api/external_person.rb
Instance Attribute Summary collapse
-
#entry ⇒ Eco::API::Common::People::PersonEntry, Hash
the input entry plain hash data used to update/create this person.
Class Method Summary collapse
Instance Method Summary collapse
Instance Attribute Details
#entry ⇒ Eco::API::Common::People::PersonEntry, Hash
the input entry plain hash data used to update/create this person.
5 6 7 |
# File 'lib/eco/api/common/version_patches/ecoportal_api/external_person.rb', line 5 def entry @entry end |
Class Method Details
.redef_without_warning(const, value) ⇒ Object
7 8 9 10 |
# File 'lib/eco/api/common/version_patches/ecoportal_api/external_person.rb', line 7 def redef_without_warning(const, value) self.class.send(:remove_const, const) if self.class.const_defined?(const) self.class.const_set(const, value) end |
Instance Method Details
#identify(section = :person) ⇒ Object
19 20 21 22 23 24 25 26 |
# File 'lib/eco/api/common/version_patches/ecoportal_api/external_person.rb', line 19 def identify(section = :person) if entry && section == :entry entry.to_s(:identify) else str_id = id ? "id: '#{id}'; " : "" "'#{name}' (#{str_id}ext_id: '#{external_id}'; email: '#{email}')" end end |