Class: Eco::API::Common::People::PersonEntry
- Includes:
- Language::AuxiliarLogger
- Defined in:
- lib/eco/api/common/people/person_entry.rb
Constant Summary collapse
- DEBUG =
false- BOOLEAN_ATTRS =
%w[ freemium accept_eula archived ].freeze
- MULTI_ATTRS =
%w[ policy_group_ids filter_tags login_provider_ids starred_ids ].freeze
- NUMERIC_ATTRS =
%w[ subordinates ].freeze
Instance Attribute Summary
Attributes included from Language::AuxiliarLogger
Instance Method Summary collapse
- #archived ⇒ Object
- #archived_flag? ⇒ Boolean
- #contractor_organization_id ⇒ Object
- #contractor_organization_id? ⇒ Boolean
- #default_tag ⇒ Object
- #default_tag? ⇒ Boolean
-
#email ⇒ String?
The email of this person if defined.
- #email? ⇒ Boolean
-
#entry(phase = :external) ⇒ Hash
The data as of at that parsing stage.
-
#external_entry ⇒ Hash
Entry
Hashwith external attribute names, and values and types thereof. -
#external_id ⇒ String?
The external id of this person if defined.
- #external_id? ⇒ Boolean
- #filter_tags ⇒ Object
- #filter_tags? ⇒ Boolean
-
#final_entry ⇒ Hash
Entry
Hashwith internal attribute names, values and types. -
#id ⇒ String?
The internal id of this person if defined.
- #id? ⇒ Boolean
-
#identify ⇒ String
Provides a reference to this person entry.
-
#idx ⇒ Integer
The entry number in the input file.
-
#initialize(data, person_parser:, attr_map:, dependencies: {}, logger: ::Logger.new(IO::NULL)) ⇒ PersonEntry
constructor
This class is meant to provide a common interface to access entries of source data that come in different formats.
-
#internal_entry ⇒ Hash
Entry
Hashwith internal attribute names and values, but external types. -
#mapped_entry ⇒ Hash
Entry
Hashwith internal attribute names, but external types and values. -
#name ⇒ String?
The name of this person if defined.
- #name? ⇒ Boolean
-
#new(data) ⇒ PersonEntry
Generates a new entry.
-
#parsing? ⇒ Boolean
To know if currently the object is in parse or serialize mode.
- #policy_group_ids ⇒ Object
- #policy_group_ids? ⇒ Boolean
-
#serializing? ⇒ Boolean
To know if currently the object is in parse or serialize mode.
-
#set_account(person, exclude: nil) ⇒ Object
Setter to fill in the
accountproperties of thePersonthat are present in theEntry. -
#set_core(person, exclude: nil) ⇒ Object
Setter to fill in all the
coreproperties of thePersonthat are present in theEntry. -
#set_details(person, exclude: nil) ⇒ Object
TO DO: use person.details.schema_id to switch @emap and @person_parser (or just crash if they don't match?) Setter to fill in all the schema
detailsfields of thePersonthat are present in theEntry. -
#supervisor_id ⇒ String?
The supervisor id of this person if defined.
- #supervisor_id=(value) ⇒ Object
- #supervisor_id? ⇒ Boolean
-
#to_s(options) ⇒ String
Provides a reference of this person entry.
Methods included from Language::AuxiliarLogger
Constructor Details
#initialize(data, person_parser:, attr_map:, dependencies: {}, logger: ::Logger.new(IO::NULL)) ⇒ PersonEntry
- if
datais aPersonobject, its behaviour isserialise. - if
datais not aPersonobject, it does aparse. - currently in rework, so there may be subtle differences that make it temporarily unstable (yet it is reliable).
This class is meant to provide a common interface to access entries of source data that come in different formats.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/eco/api/common/people/person_entry.rb', line 36 def initialize(data, person_parser:, attr_map:, dependencies: {}, logger: ::Logger.new(IO::NULL)) msg = "Constructor needs a PersonParser. Given: #{person_parser.class}" raise msg unless person_parser.is_a?(Eco::API::Common::People::PersonParser) msg = "Expecting Mapper object. Given: #{attr_map.class}" raise msg if attr_map && !attr_map.is_a?(Eco::Data::Mapper) @source = data @person_parser = person_parser @deps = dependencies @logger = logger @attr_map = attr_map @emap = PersonEntryAttributeMapper.new( @source, person_parser: @person_parser, attr_map: @attr_map, logger: @logger ) if parsing? @external_entry = __external_entry(data) @mapped_entry = __mapped_entry(@external_entry) @internal_entry = __internal_entry(@mapped_entry) @final_entry = __final_entry(@internal_entry) else # SERIALIZING @person = data @final_entry = __final_entry(@person) @internal_entry = __internal_entry(@final_entry) @mapped_entry = __mapped_entry(@internal_entry) @external_entry = __external_entry(@mapped_entry) end (print_models; exit(1)) if DEBUG # rubocop:disable Style/Semicolon end |
Instance Method Details
#archived ⇒ Object
163 164 165 |
# File 'lib/eco/api/common/people/person_entry.rb', line 163 def archived final_entry['archived'] end |
#archived_flag? ⇒ Boolean
167 168 169 |
# File 'lib/eco/api/common/people/person_entry.rb', line 167 def archived_flag? final_entry.key?('archived') end |
#contractor_organization_id ⇒ Object
210 211 212 |
# File 'lib/eco/api/common/people/person_entry.rb', line 210 def contractor_organization_id final_entry['contractor_organization_id'] end |
#contractor_organization_id? ⇒ Boolean
214 215 216 |
# File 'lib/eco/api/common/people/person_entry.rb', line 214 def contractor_organization_id? final_entry.key?('contractor_organization_id') end |
#default_tag ⇒ Object
230 231 232 |
# File 'lib/eco/api/common/people/person_entry.rb', line 230 def default_tag final_entry['default_tag'] end |
#default_tag? ⇒ Boolean
226 227 228 |
# File 'lib/eco/api/common/people/person_entry.rb', line 226 def default_tag? final_entry.key?('default_tag') end |
#email ⇒ String?
Returns the email of this person if defined.
181 182 183 |
# File 'lib/eco/api/common/people/person_entry.rb', line 181 def email final_entry['email'] end |
#email? ⇒ Boolean
185 186 187 |
# File 'lib/eco/api/common/people/person_entry.rb', line 185 def email? final_entry.key?('email') end |
#entry(phase = :external) ⇒ Hash
Returns the data as of at that parsing stage.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/eco/api/common/people/person_entry.rb', line 84 def entry(phase = :external) phase = phase.to_sym case phase when :external external_entry when :mapped mapped_entry when :internal internal_entry when :final final_entry else raise ArgumentError, "Unknown phase '#{phase}'" end end |
#external_entry ⇒ Hash
completely serialized entry.
Returns entry Hash with external attribute names, and values and types thereof.
103 104 105 |
# File 'lib/eco/api/common/people/person_entry.rb', line 103 def external_entry # rubocop:disable Style/TrivialAccessors @external_entry end |
#external_id ⇒ String?
Returns the external id of this person if defined.
155 156 157 |
# File 'lib/eco/api/common/people/person_entry.rb', line 155 def external_id final_entry['external_id'] end |
#external_id? ⇒ Boolean
159 160 161 |
# File 'lib/eco/api/common/people/person_entry.rb', line 159 def external_id? final_entry.key?('external_id') end |
#filter_tags ⇒ Object
202 203 204 |
# File 'lib/eco/api/common/people/person_entry.rb', line 202 def final_entry['filter_tags'] || [] end |
#filter_tags? ⇒ Boolean
206 207 208 |
# File 'lib/eco/api/common/people/person_entry.rb', line 206 def final_entry.key?('filter_tags') end |
#final_entry ⇒ Hash
values ready to be set to a person.
Returns entry Hash with internal attribute names, values and types.
123 124 125 |
# File 'lib/eco/api/common/people/person_entry.rb', line 123 def final_entry # rubocop:disable Style/TrivialAccessors @final_entry end |
#id ⇒ String?
Returns the internal id of this person if defined.
146 147 148 |
# File 'lib/eco/api/common/people/person_entry.rb', line 146 def id final_entry['id'] end |
#id? ⇒ Boolean
150 151 152 |
# File 'lib/eco/api/common/people/person_entry.rb', line 150 def id? final_entry.key?('id') end |
#identify ⇒ String
Provides a reference to this person entry.
236 237 238 239 240 241 242 |
# File 'lib/eco/api/common/people/person_entry.rb', line 236 def identify str_id = id ? "id: '#{id}'; " : '' str = "(row: #{idx}) '#{name}' " str << "(#{str_id}ext_id: '#{external_id}'; " str << "email: '#{email}')" str end |
#idx ⇒ Integer
Eco::API::Common::People::EntryFactory#entries adds this idx (i.e. row number)
Returns the entry number in the input file.
141 142 143 |
# File 'lib/eco/api/common/people/person_entry.rb', line 141 def idx final_entry['idx'] end |
#internal_entry ⇒ Hash
just one step away from being completely parsed (only types parsing pending).
Returns entry Hash with internal attribute names and values,
but external types.
110 111 112 |
# File 'lib/eco/api/common/people/person_entry.rb', line 110 def internal_entry # rubocop:disable Style/TrivialAccessors @internal_entry end |
#mapped_entry ⇒ Hash
at this stage, only the header names have been converted/transformed.
Returns entry Hash with internal attribute names,
but external types and values.
117 118 119 |
# File 'lib/eco/api/common/people/person_entry.rb', line 117 def mapped_entry # rubocop:disable Style/TrivialAccessors @mapped_entry end |
#name ⇒ String?
Returns the name of this person if defined.
172 173 174 |
# File 'lib/eco/api/common/people/person_entry.rb', line 172 def name final_entry['name'] end |
#name? ⇒ Boolean
176 177 178 |
# File 'lib/eco/api/common/people/person_entry.rb', line 176 def name? final_entry.key?('name') end |
#new(data) ⇒ PersonEntry
Generates a new entry
73 74 75 76 77 78 79 80 81 |
# File 'lib/eco/api/common/people/person_entry.rb', line 73 def new(data) self.class.new( data, person_parser: @person_parser, attr_map: @attr_map, dependencies: @deps, logger: @logger ) end |
#parsing? ⇒ Boolean
To know if currently the object is in parse or serialize mode.
129 130 131 |
# File 'lib/eco/api/common/people/person_entry.rb', line 129 def parsing? !@source.is_a?(Ecoportal::API::Internal::Person) end |
#policy_group_ids ⇒ Object
218 219 220 |
# File 'lib/eco/api/common/people/person_entry.rb', line 218 def policy_group_ids final_entry['policy_group_ids'] || [] end |
#policy_group_ids? ⇒ Boolean
222 223 224 |
# File 'lib/eco/api/common/people/person_entry.rb', line 222 def policy_group_ids? final_entry.key?('policy_group_ids') end |
#serializing? ⇒ Boolean
To know if currently the object is in parse or serialize mode.
135 136 137 |
# File 'lib/eco/api/common/people/person_entry.rb', line 135 def serializing? !parsing? end |
#set_account(person, exclude: nil) ⇒ Object
it only sets those account properties defined in the entry. Meaning that if an account property is not present in the entry, this will not be set on the target person.
Setter to fill in the account properties of the Person that are present in the Entry.
281 282 283 284 285 286 287 288 |
# File 'lib/eco/api/common/people/person_entry.rb', line 281 def set_account(person, exclude: nil) person.account = {} unless person.account scoped_attrs = @emap.account_attrs(@final_entry) - into_a(exclude) @final_entry.slice(*scoped_attrs).each do |attr, value| set_part(person.account, attr, value) end end |
#set_core(person, exclude: nil) ⇒ Object
- it only sets those core properties defined in the entry. Meaning that if an core property is not present in the entry, this will not be set on the target person.
- if there's an incorrect email exception, it blanks the email and logs a warning message
Setter to fill in all the core properties of the Person that are present in the Entry.
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/eco/api/common/people/person_entry.rb', line 262 def set_core(person, exclude: nil) scoped_attrs = @emap.core_attrs(@final_entry) - into_a(exclude) scoped_attrs -= ['id'] @final_entry.slice(*scoped_attrs).each do |attr, value| set_part(person, attr, value) rescue StandardError => e raise unless attr == 'email' log(:error) { "#{e} - setting blank email instead." } set_part(person, attr, nil) end end |
#set_details(person, exclude: nil) ⇒ Object
it only sets those details properties defined in the entry. Meaning that if an details property is not present in the entry, this will not be set on the target person.
TO DO: use person.details.schema_id to switch @emap and @person_parser (or just crash if they don't match?)
Setter to fill in all the schema details fields of the Person that are present in the Entry.
296 297 298 299 300 301 302 303 304 305 |
# File 'lib/eco/api/common/people/person_entry.rb', line 296 def set_details(person, exclude: nil) person.add_details(@person_parser.schema) if !person.details || !person.details.schema_id scoped_attrs = @emap.details_attrs(@final_entry) - into_a(exclude) @final_entry.slice( *scoped_attrs ).each do |attr, value| set_part(person.details, attr, value) end end |
#supervisor_id ⇒ String?
Returns the supervisor id of this person if defined.
190 191 192 |
# File 'lib/eco/api/common/people/person_entry.rb', line 190 def supervisor_id final_entry['supervisor_id'] end |
#supervisor_id=(value) ⇒ Object
194 195 196 |
# File 'lib/eco/api/common/people/person_entry.rb', line 194 def supervisor_id=(value) final_entry['supervisor_id'] = value end |
#supervisor_id? ⇒ Boolean
198 199 200 |
# File 'lib/eco/api/common/people/person_entry.rb', line 198 def supervisor_id? final_entry.key?('supervisor_id') end |
#to_s(options) ⇒ String
Provides a reference of this person entry.
246 247 248 249 250 251 252 253 |
# File 'lib/eco/api/common/people/person_entry.rb', line 246 def to_s() = into_a() return identify if .include?(:identify) final_entry.each.map do |k, v| "'#{k}': '#{v.to_json}'" end.join(' | ') end |