Class: Eco::API::Common::People::PersonEntry

Inherits:
Object
  • Object
show all
Includes:
Language::AuxiliarLogger
Defined in:
lib/eco/api/common/people/person_entry.rb

Constant Summary collapse

DEBUG =
false

Instance Attribute Summary

Attributes included from Language::AuxiliarLogger

#logger

Instance Method Summary collapse

Methods included from Language::AuxiliarLogger

#log

Constructor Details

#initialize(data, person_parser:, attr_map:, dependencies: {}, logger: ::Logger.new(IO::NULL)) ⇒ PersonEntry

Note:
  • if data is a Person object, its behaviour is serialise.
  • if data is not a Person object, it does a parse.
  • currently in rework, so there may be subtle differences that make it temporarily unstable (yet it is reliable).

This class is meant to provide a common interface to access entries of source data that come in different formats.

Parameters:

  • data (Hash, Ecoportal::API::V1::Person)

    Person object to be serialized or hashed entry (CSV::Row is accepted).

  • person_parser (Common::People::PersonParser)

    parser/serializer of person attributes (it contains a set of attribute parsers).

  • attr_map (Eco::Data::Mapper)

    mapper to translate attribute names from external to internal names and vice versa.

  • dependencies (Hash) (defaults to: {})

    hash where keys are internal attribute names. It is mostly used to deliver final dependencies to attribute parsers/serializers.

  • logger (Common::Session::Logger, ::Logger) (defaults to: ::Logger.new(IO::NULL))

    object to managelogs.



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/eco/api/common/people/person_entry.rb', line 26

def initialize(data, person_parser:, attr_map:, dependencies: {}, logger: ::Logger.new(IO::NULL))
  msg = "Constructor needs a PersonParser. Given: #{person_parser.class}"
  raise msg unless person_parser.is_a?(Eco::API::Common::People::PersonParser)

  msg = "Expecting Mapper object. Given: #{attr_map.class}"
  raise msg if attr_map && !attr_map.is_a?(Eco::Data::Mapper)

  @source        = data
  @person_parser = person_parser
  @deps          = dependencies
  @logger        = logger
  @attr_map      = attr_map
  @emap          = PersonEntryAttributeMapper.new(
    @source,
    person_parser: @person_parser,
    attr_map:      @attr_map,
    logger:        @logger
  )

  if parsing?
    @external_entry     = __external_entry(data)
    @mapped_entry       = __mapped_entry(@external_entry)
    @internal_entry     = __internal_entry(@mapped_entry)
    @final_entry        = __final_entry(@internal_entry)
  else  # SERIALIZING
    @person             = data
    @final_entry        = __final_entry(@person)
    @internal_entry     = __internal_entry(@final_entry)
    @mapped_entry       = __mapped_entry(@internal_entry)
    @external_entry     = __external_entry(@mapped_entry)
  end

  (print_models; exit(1)) if DEBUG # rubocop:disable Style/Semicolon
end

Instance Method Details

#archivedObject



132
133
134
# File 'lib/eco/api/common/people/person_entry.rb', line 132

def archived
  final_entry['archived']
end

#archived_flag?Boolean

Returns:

  • (Boolean)


136
137
138
# File 'lib/eco/api/common/people/person_entry.rb', line 136

def archived_flag?
  final_entry.key?('archived')
end

#contractor_organization_idObject



179
180
181
# File 'lib/eco/api/common/people/person_entry.rb', line 179

def contractor_organization_id
  final_entry['contractor_organization_id']
end

#contractor_organization_id?Boolean

Returns:

  • (Boolean)


183
184
185
# File 'lib/eco/api/common/people/person_entry.rb', line 183

def contractor_organization_id?
  final_entry.key?('contractor_organization_id')
end

#default_tagObject



199
200
201
# File 'lib/eco/api/common/people/person_entry.rb', line 199

def default_tag
  final_entry['default_tag']
end

#default_tag?Boolean

Returns:

  • (Boolean)


195
196
197
# File 'lib/eco/api/common/people/person_entry.rb', line 195

def default_tag?
  final_entry.key?('default_tag')
end

#emailString?

Returns the email of this person if defined.

Returns:

  • (String, nil)

    the email of this person if defined.



150
151
152
# File 'lib/eco/api/common/people/person_entry.rb', line 150

def email
  final_entry['email']
end

#email?Boolean

Returns:

  • (Boolean)


154
155
156
# File 'lib/eco/api/common/people/person_entry.rb', line 154

def email?
  final_entry.key?('email')
end

#external_entryHash

Note:

completely serialized entry.

Returns entry Hash with external attribute names, and values and types thereof.

Returns:

  • (Hash)

    entry Hash with external attribute names, and values and types thereof.



75
76
77
# File 'lib/eco/api/common/people/person_entry.rb', line 75

def external_entry # rubocop:disable Style/TrivialAccessors
  @external_entry
end

#external_idString?

Returns the external id of this person if defined.

Returns:

  • (String, nil)

    the external id of this person if defined.



124
125
126
# File 'lib/eco/api/common/people/person_entry.rb', line 124

def external_id
  final_entry['external_id']
end

#external_id?Boolean

Returns:

  • (Boolean)


128
129
130
# File 'lib/eco/api/common/people/person_entry.rb', line 128

def external_id?
  final_entry.key?('external_id')
end

#filter_tagsObject



171
172
173
# File 'lib/eco/api/common/people/person_entry.rb', line 171

def filter_tags
  final_entry['filter_tags'] || []
end

#filter_tags?Boolean

Returns:

  • (Boolean)


175
176
177
# File 'lib/eco/api/common/people/person_entry.rb', line 175

def filter_tags?
  final_entry.key?('filter_tags')
end

#final_entryHash

Note:

values ready to be set to a person.

Returns entry Hash with internal attribute names, values and types.

Returns:

  • (Hash)

    entry Hash with internal attribute names, values and types.



92
93
94
# File 'lib/eco/api/common/people/person_entry.rb', line 92

def final_entry # rubocop:disable Style/TrivialAccessors
  @final_entry
end

#idString?

Returns the internal id of this person if defined.

Returns:

  • (String, nil)

    the internal id of this person if defined.



115
116
117
# File 'lib/eco/api/common/people/person_entry.rb', line 115

def id
  final_entry['id']
end

#id?Boolean

Returns:

  • (Boolean)


119
120
121
# File 'lib/eco/api/common/people/person_entry.rb', line 119

def id?
  final_entry.key?('id')
end

#identifyString

Provides a reference to this person entry.

Returns:

  • (String)

    string summary of this person identity.



205
206
207
208
# File 'lib/eco/api/common/people/person_entry.rb', line 205

def identify
  str_id = id ? "id: '#{id}'; " : ''
  "(row: #{idx}) '#{name}' (#{str_id}ext_id: '#{external_id}'; email: '#{email}')"
end

#idxInteger

Note:

Eco::API::Common::People::EntryFactory#entries adds this idx (i.e. row number)

Returns the entry number in the input file.

Returns:

  • (Integer)

    the entry number in the input file



110
111
112
# File 'lib/eco/api/common/people/person_entry.rb', line 110

def idx
  final_entry['idx']
end

#internal_entryHash

Note:

just one step away from being completely parsed (only types parsing pending).

Returns entry Hash with internal attribute names and values, but external types.

Returns:

  • (Hash)

    entry Hash with internal attribute names and values, but external types.



81
82
83
# File 'lib/eco/api/common/people/person_entry.rb', line 81

def internal_entry # rubocop:disable Style/TrivialAccessors
  @internal_entry
end

#mapped_entryHash

Returns entry Hash with internal attribute names, but external types and values.

Returns:

  • (Hash)

    entry Hash with internal attribute names, but external types and values.



86
87
88
# File 'lib/eco/api/common/people/person_entry.rb', line 86

def mapped_entry # rubocop:disable Style/TrivialAccessors
  @mapped_entry
end

#nameString?

Returns the name of this person if defined.

Returns:

  • (String, nil)

    the name of this person if defined.



141
142
143
# File 'lib/eco/api/common/people/person_entry.rb', line 141

def name
  final_entry['name']
end

#name?Boolean

Returns:

  • (Boolean)


145
146
147
# File 'lib/eco/api/common/people/person_entry.rb', line 145

def name?
  final_entry.key?('name')
end

#new(data) ⇒ PersonEntry

Generates a new entry

Returns:



63
64
65
66
67
68
69
70
71
# File 'lib/eco/api/common/people/person_entry.rb', line 63

def new(data)
  self.class.new(
    data,
    person_parser: @person_parser,
    attr_map:      @attr_map,
    dependencies:  @deps,
    logger:        @logger
  )
end

#parsing?Boolean

To know if currently the object is in parse or serialize mode.

Returns:

  • (Boolean)

    returns true if we are parsing, false otherwise.



98
99
100
# File 'lib/eco/api/common/people/person_entry.rb', line 98

def parsing?
  !@source.is_a?(Ecoportal::API::Internal::Person)
end

#policy_group_idsObject



187
188
189
# File 'lib/eco/api/common/people/person_entry.rb', line 187

def policy_group_ids
  final_entry['policy_group_ids'] || []
end

#policy_group_ids?Boolean

Returns:

  • (Boolean)


191
192
193
# File 'lib/eco/api/common/people/person_entry.rb', line 191

def policy_group_ids?
  final_entry.key?('policy_group_ids')
end

#serializing?Boolean

To know if currently the object is in parse or serialize mode.

Returns:

  • (Boolean)

    returns true if we are serializing, false otherwise.



104
105
106
# File 'lib/eco/api/common/people/person_entry.rb', line 104

def serializing?
  !parsing?
end

#set_account(person, exclude: nil) ⇒ Object

Note:

it only sets those account properties defined in the entry. Meaning that if an account property is not present in the entry, this will not be set on the target person.

Setter to fill in the account properties of the Person that are present in the Entry.

Parameters:

  • person (Ecoportal::API::Internal::Person)

    the person we want to set the account values to.

  • exclude (String, Array<String>) (defaults to: nil)

    account properties that should not be set/changed to the person.



248
249
250
251
252
253
254
# File 'lib/eco/api/common/people/person_entry.rb', line 248

def (person, exclude: nil)
  person. = {} unless person.
  scoped_attrs = @emap.(@final_entry) - into_a(exclude)
  @final_entry.slice(*scoped_attrs).each do |attr, value|
    set_part(person., attr, value)
  end
end

#set_core(person, exclude: nil) ⇒ Object

Note:
  1. it only sets those core properties defined in the entry. Meaning that if an core property is not present in the entry, this will not be set on the target person.
  2. if there's an incorrect email exception, it blanks the email and logs a warning message

Setter to fill in all the core properties of the Person that are present in the Entry.

Parameters:

  • person (Ecoportal::API::V1::Person)

    the person we want to set the core values to.

  • exclude (String, Array<String>) (defaults to: nil)

    core attributes that should not be set/changed to the person.



230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/eco/api/common/people/person_entry.rb', line 230

def set_core(person, exclude: nil)
  scoped_attrs  = @emap.core_attrs(@final_entry) - into_a(exclude)
  scoped_attrs -= ['id']
  @final_entry.slice(*scoped_attrs).each do |attr, value|
    set_part(person, attr, value)
  rescue StandardError => e
    raise unless attr == 'email'

    log(:error) { "#{e} - setting blank email instead." }
    set_part(person, attr, nil)
  end
end

#set_details(person, exclude: nil) ⇒ Object

Note:

it only sets those details properties defined in the entry. Meaning that if an details property is not present in the entry, this will not be set on the target person.

TO DO: use person.details.schema_id to switch @emap and @person_parser (or just crash if they don't match?) Setter to fill in all the schema details fields of the Person that are present in the Entry.

Parameters:

  • person (Ecoportal::API::V1::Person)

    the person we want to set the schema fields' values to.

  • exclude (String, Array<String>) (defaults to: nil)

    schema field attributes that should not be set/changed to the person.



262
263
264
265
266
267
268
# File 'lib/eco/api/common/people/person_entry.rb', line 262

def set_details(person, exclude: nil)
  person.add_details(@person_parser.schema) if !person.details || !person.details.schema_id
  scoped_attrs = @emap.details_attrs(@final_entry) - into_a(exclude)
  @final_entry.slice(*scoped_attrs).each do |attr, value|
    set_part(person.details, attr, value)
  end
end

#supervisor_idString?

Returns the supervisor id of this person if defined.

Returns:

  • (String, nil)

    the supervisor id of this person if defined.



159
160
161
# File 'lib/eco/api/common/people/person_entry.rb', line 159

def supervisor_id
  final_entry['supervisor_id']
end

#supervisor_id=(value) ⇒ Object



163
164
165
# File 'lib/eco/api/common/people/person_entry.rb', line 163

def supervisor_id=(value)
  final_entry['supervisor_id'] = value
end

#supervisor_id?Boolean

Returns:

  • (Boolean)


167
168
169
# File 'lib/eco/api/common/people/person_entry.rb', line 167

def supervisor_id?
  final_entry.key?('supervisor_id')
end

#to_s(options) ⇒ String

Provides a reference of this person entry.

Returns:

  • (String)

    string summary of this person identity.



212
213
214
215
216
217
218
219
220
221
# File 'lib/eco/api/common/people/person_entry.rb', line 212

def to_s(options)
  options = into_a(options)
  if options.include?(:identify)
    identify
  else
    final_entry.each.map do |k, v|
      "'#{k}': '#{v.to_json}'"
    end.join(' | ')
  end
end