Class: Eco::API::UseCases::Default::Utils::MergeCsv

Inherits:
Custom::UseCase show all
Defined in:
lib/eco/api/usecases/default/utils/merge_csv_case.rb,
lib/eco/api/usecases/default/utils/cli/merge_csv_cli.rb

Overview

Note:

you might run first the sort-csv case.

Note:

at the moment, it does NOT add new fields from the merge file. It only uses the headers of the original file.

Note:

you must inherit from this case and define the constants.

MERGE_BY_FIELD = 'target_csv_field'.freeze

those not merged are overridden

JOINED_FIELDS = [ 'joined_field_1', 'joined_field_2', 'joined_field_3', ].freeze

This script assumes that for the MERGE_BY_FIELD rows are consecutive.

Defined Under Namespace

Classes: Cli

Instance Attribute Summary

Attributes included from Language::AuxiliarLogger

#logger

Instance Method Summary collapse

Methods inherited from Common::Loaders::UseCase

#cli_apply!, #initialize

Methods included from Common::Loaders::UseCase::CliIdentify

#cli, #cli!

Methods included from Common::Loaders::UseCase::TargetModel

#target_model

Methods included from Common::Loaders::UseCase::Type

#type

Methods inherited from Common::Loaders::CaseBase

#name, name_only_once!, original_name

Methods inherited from Common::Loaders::Base

<=>, created_at, #initialize, set_created_at!

Methods included from Language::Klass::InheritableClassVars

#inheritable_attrs, #inheritable_class_vars, #inherited

Methods included from Language::Klass::Naming

#instance_variable_name, #to_constant

Methods included from Language::Klass::Hierarchy

#descendants, #descendants?

Methods included from Language::Klass::Builder

#new_class

Methods included from Language::Klass::Uid

#uid

Methods included from Language::Klass::Resolver

#class_resolver, #resolve_class

Methods included from Language::Klass::Const

#if_const, #redef_without_warning

Methods included from Language::AuxiliarLogger

#log

Constructor Details

This class inherits a constructor from Eco::API::Common::Loaders::UseCase

Instance Method Details

#main(*_args) ⇒ Object



21
22
23
24
25
26
27
28
# File 'lib/eco/api/usecases/default/utils/merge_csv_case.rb', line 21

def main(*_args)
  if simulate?
    count = Eco::CSV.count(input_file)
    log(:info) { "CSV '#{input_file}' has #{count} rows." }
  else
    generate_file
  end
end