Class: Eco::API::UseCases::Default::Utils::MergeCsv
- Inherits:
-
Custom::UseCase
- Object
- Common::Loaders::Base
- Common::Loaders::CaseBase
- Common::Loaders::UseCase
- Custom::UseCase
- Eco::API::UseCases::Default::Utils::MergeCsv
- Defined in:
- lib/eco/api/usecases/default/utils/merge_csv_case.rb,
lib/eco/api/usecases/default/utils/cli/merge_csv_cli.rb
Overview
you might run first the sort-csv case.
at the moment, it does NOT add new fields from the merge file. It only uses the headers of the original file.
you must inherit from this case and define the constants.
MERGE_BY_FIELD = 'target_csv_field'.freeze
those not merged are overridden
JOINED_FIELDS = [ 'joined_field_1', 'joined_field_2', 'joined_field_3', ].freeze
This script assumes that for the MERGE_BY_FIELD rows are consecutive.
Defined Under Namespace
Classes: Cli
Instance Attribute Summary
Attributes included from Language::AuxiliarLogger
Instance Method Summary collapse
Methods inherited from Common::Loaders::UseCase
Methods included from Common::Loaders::UseCase::CliIdentify
Methods included from Common::Loaders::UseCase::TargetModel
Methods included from Common::Loaders::UseCase::Type
Methods inherited from Common::Loaders::CaseBase
#name, name_only_once!, original_name
Methods inherited from Common::Loaders::Base
<=>, created_at, #initialize, set_created_at!
Methods included from Language::Klass::InheritableClassVars
#inheritable_attrs, #inheritable_class_vars, #inherited
Methods included from Language::Klass::Naming
#instance_variable_name, #to_constant
Methods included from Language::Klass::Hierarchy
Methods included from Language::Klass::Builder
Methods included from Language::Klass::Uid
Methods included from Language::Klass::Resolver
#class_resolver, #resolve_class
Methods included from Language::Klass::Const
#if_const, #redef_without_warning
Methods included from Language::AuxiliarLogger
Constructor Details
This class inherits a constructor from Eco::API::Common::Loaders::UseCase