Module: Eco::API::UseCases::Lib::Base::Env
- Defined in:
- lib/eco/api/usecases/lib/base/env.rb
Overview
Note:
this is intended to be at the foremost part upfront: with prepend.
Basic stuff you would need in any use case
Defined Under Namespace
Modules: InstanceMethods
Class Method Summary collapse
Class Method Details
.included(base) ⇒ Object
6 7 8 9 10 11 |
# File 'lib/eco/api/usecases/lib/base/env.rb', line 6 def included(base) super base.send :include, Eco::Language::AuxiliarLogger base.prepend(InstanceMethods) end |