Module: Eco::Language::Delegation::ConstLookupHooks
- Defined in:
- lib/eco/language/delegation/const_lookup_hooks.rb
Overview
Note:
it includes ConstDelegator (which includes DelegatedClass)
Note:
for each not inherited constant that isn't part of the delegated object's class, it will create a undercore/snake named instance method, to ease constant lookup througout chained/wrapped delegators.
This approach only makes sense to be used in Delegator and related helpers.
Defined Under Namespace
Modules: ClassMethods